@@ -1,21 +1,21 @@
 /*
-mediastreamer2 library - modular sound and video processing and streaming
-Copyright (C) 2006  Simon MORLAT (simon.morlat@linphone.org)
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ *
+ * This file is part of mediastreamer2.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #ifndef msfilter_h
 #define msfilter_h
@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "mediastreamer2/msqueue.h"
 #include "mediastreamer2/allfilters.h"
 #include "mediastreamer2/formats.h"
+#include "mediastreamer2/box-plot.h"
 
 /**
  * @file msfilter.h
@@ -85,6 +86,7 @@ enum _MSFilterInterfaceId{
 	MSFilterAudioCaptureInterface,/**<Interface for audio capture filters*/
 	MSFilterAudioPlaybackInterface,/**Interface for audio playback filters.*/
 	MSFilterAudioEncoderInterface,/**<Video encoder interface*/
+	MSFilterVADInterface,/**<Voice activity detection interface*/
 	MSFilterVoidInterface,/**<Void source/sink interface*/
 };
 
@@ -147,8 +149,7 @@ typedef enum _MSFilterFlags MSFilterFlags;
 
 struct _MSFilterStats{
 	const char *name; /*<filter name*/
-	uint64_t elapsed; /*<cumulative number of nanoseconds elapsed */
-	unsigned int count; /*<number of time the filter is called for processing*/
+	MSUBoxPlot bp_elapsed; /* box plot for elapsed time in filter process in nanoseconds */
 };
 
 typedef struct _MSFilterStats MSFilterStats;
@@ -246,6 +247,8 @@ extern "C"{
  */
 MS2_PUBLIC MS2_DEPRECATED void ms_filter_register(MSFilterDesc *desc);
 
+
+
 /**
  * Retrieve capture filter that supports encoding to codec name.
  *
@@ -311,7 +314,7 @@ MS2_PUBLIC MS2_DEPRECATED MSList *ms_filter_lookup_by_interface(MSFilterInterfac
 
 /**
  * Create encoder filter according to codec name.
- 
+
  * @param mime    A string indicating the codec.
  *
  * @return a MSFilter if successfull, NULL otherwise.
@@ -436,7 +439,7 @@ MS2_PUBLIC bool_t ms_filter_has_method(MSFilter *f, unsigned int id);
  * Returns whether a filter implements a given interface.
  * @param f a MSFilter object
  * @param id an interface id.
- * 
+ *
  * Returns TRUE if interface is implemented, FALSE, otherwise.
 **/
 MS2_PUBLIC bool_t ms_filter_implements_interface(MSFilter *f, MSFilterInterfaceId id);
@@ -445,24 +448,11 @@ MS2_PUBLIC bool_t ms_filter_implements_interface(MSFilter *f, MSFilterInterfaceI
  * Returns whether a filter implements a given interface, based on the filter's descriptor.
  * @param f a MSFilter object
  * @param id an interface id.
- * 
+ *
  * Returns TRUE if interface is implemented, FALSE, otherwise.
 **/
 MS2_PUBLIC bool_t ms_filter_desc_implements_interface(MSFilterDesc *desc, MSFilterInterfaceId id);
 
-/**
- * Set a callback on filter's to be informed of private filter's event.
- * This callback is called from the filter's MSTicker, unless a global event queue
- * is created to receive all filter's notification asynchronously.
- * See ms_event_queue_new() for details.
- *
- * @param f        A MSFilter object.
- * @param fn       A MSFilterNotifyFunc that will be called.
- * @param userdata A pointer to private data.
- * @deprecated use ms_filter_add_notify_callback()
- *
- */
-
 
 /**
  * Set a callback on filter's to be informed of private filter's event.
@@ -607,7 +597,7 @@ MS2_PUBLIC MS2_DEPRECATED void ms_filter_log_statistics(void);
 the method index (_cnt_) and the argument size */
 /* I hope using this to avoid type mismatch (calling a method on the wrong filter)*/
 #define MS_FILTER_METHOD_ID(_id_,_cnt_,_argsize_) \
-	(  (((unsigned long)(_id_)) & 0xFFFF)<<16 | (_cnt_<<8) | (_argsize_ & 0xFF ))
+	(unsigned int)(((((unsigned int)(_id_)) & 0xFFFF)<<16) | (((unsigned int)(_cnt_))<<8) | (((unsigned int)_argsize_) & 0xFF))
 
 /**
  * Macro to create a method id, unique per filter.
@@ -637,13 +627,13 @@ the method index (_cnt_) and the argument size */
 #define MS_FILTER_EVENT_NO_ARG(_id_,_count_)\
 	MS_FILTER_METHOD_ID(_id_,_count_,0)
 
-	
+
 #define MS_FILTER_BASE_EVENT(_count_,_argtype_) \
 	MS_FILTER_EVENT(MS_FILTER_BASE_ID,_count_,_argtype_)
 
 #define MS_FILTER_BASE_EVENT_NO_ARG(_count_) \
 	MS_FILTER_EVENT_NO_ARG(MS_FILTER_BASE_ID,_count_)
-	
+
 /**
  *  some MSFilter base generic methods:
  **/
@@ -705,7 +695,6 @@ typedef struct _MSPinFormat{
 **/
 #define MS_FILTER_OUTPUT_FMT_CHANGED MS_FILTER_BASE_EVENT_NO_ARG(0) /**<triggered whenever a filter decides to change its output format for one or more more output pins*/
 
-
 /* DEPRECATED  specific methods: to be moved into implementation specific header files - DO NOT USE IN NEW CODE*/
 #define MS_FILTER_SET_FILTERLENGTH 	MS_FILTER_BASE_METHOD(12,int)
 #define MS_FILTER_SET_OUTPUT_SAMPLE_RATE MS_FILTER_BASE_METHOD(13,int)
@@ -736,7 +725,7 @@ MS2_PUBLIC void ms_filter_postprocess(MSFilter *f);
 MS2_PUBLIC bool_t ms_filter_inputs_have_data(MSFilter *f);
 MS2_PUBLIC void ms_filter_notify(MSFilter *f, unsigned int id, void *arg);
 MS2_PUBLIC void ms_filter_notify_no_arg(MSFilter *f, unsigned int id);
-void ms_filter_clear_notify_callback(MSFilter *f);
+MS2_PUBLIC void ms_filter_clear_notify_callback(MSFilter *f);
 void ms_filter_clean_pending_events(MSFilter *f);
 #define ms_filter_lock(f)	ms_mutex_lock(&(f)->lock)
 #define ms_filter_unlock(f)	ms_mutex_unlock(&(f)->lock)
